import {Refine, Authenticated} from '@refinedev/core'
import {DevtoolsPanel, DevtoolsProvider} from '@refinedev/devtools'
import {RefineKbar, RefineKbarProvider} from '@refinedev/kbar'

import {ErrorComponent, useNotificationProvider, RefineSnackbarProvider, ThemedLayoutV2} from '@refinedev/mui'

import dataProvider from '@refinedev/simple-rest'
import CssBaseline from '@mui/material/CssBaseline'
import GlobalStyles from '@mui/material/GlobalStyles'
import {BrowserRouter, Route, Routes, Outlet} from 'react-router'
import routerBindings, {NavigateToResource, CatchAllNavigate, UnsavedChangesNotifier, DocumentTitleHandler} from '@refinedev/react-router'
import {ColorModeContextProvider} from './contexts/color-mode'
import {Header} from './components/header'
import {Login} from './pages/login'
import {Register} from './pages/register'
import {ForgotPassword} from './pages/forgotPassword'
import {authProvider} from './authProvider'

// import {BlogPostList, BlogPostCreate, BlogPostEdit, BlogPostShow} from './pages/blog-posts'
// import {CategoryList, CategoryCreate, CategoryEdit, CategoryShow} from './pages/categories'

import {CountryList, CountryCreate, CountryEdit} from './pages/country'
import {CityList, CityCreate, CityEdit} from './pages/city'
import {CarrierList, CarrierCreate, CarrierEdit} from './pages/carrier'

function App() {
  return (
    <BrowserRouter>
      <RefineKbarProvider>
        <ColorModeContextProvider>
          <CssBaseline />
          <GlobalStyles styles={{html: {WebkitFontSmoothing: 'auto'}}} />
          <RefineSnackbarProvider>
            <DevtoolsProvider>
              <Refine
                dataProvider={dataProvider('https://wn.krbl.ru')} // https://api.fake-rest.refine.dev
                notificationProvider={useNotificationProvider}
                routerProvider={routerBindings}
                authProvider={authProvider}
                resources={[
                  // {
                  //   name: 'blog_posts',
                  //   list: '/blog-posts',
                  //   create: '/blog-posts/create',
                  //   edit: '/blog-posts/edit/:id',
                  //   show: '/blog-posts/show/:id',
                  //   meta: {
                  //     canDelete: true,
                  //   },
                  // },
                  // {
                  //   name: 'categories',
                  //   list: '/categories',
                  //   create: '/categories/create',
                  //   edit: '/categories/edit/:id',
                  //   show: '/categories/show/:id',
                  //   meta: {
                  //     canDelete: true,
                  //   },
                  // },

                  {
                    name: 'country',
                    list: '/country',
                    create: '/country/create',
                    edit: '/country/edit/:id',
                    meta: {
                      canDelete: true,
                    },
                  },
                  {
                    name: 'city',
                    list: '/city',
                    create: '/city/create',
                    edit: '/city/edit/:id',
                    meta: {
                      canDelete: true,
                    },
                  },
                  {
                    name: 'carrier',
                    list: '/carrier',
                    create: '/carrier/create',
                    edit: '/carrier/edit/:id',
                    meta: {
                      canDelete: true,
                    },
                  },
                ]}
                options={{
                  syncWithLocation: true,
                  warnWhenUnsavedChanges: true,
                  useNewQueryKeys: true,
                  projectId: 'Wv044J-t53S3s-PcbJGe',
                }}
              >
                <Routes>
                  <Route
                    element={
                      <Authenticated key="authenticated-inner" fallback={<CatchAllNavigate to="/login" />}>
                        <ThemedLayoutV2 Header={Header}>
                          <Outlet />
                        </ThemedLayoutV2>
                      </Authenticated>
                    }
                  >
                    <Route index element={<NavigateToResource resource="country" />} />
                    {/* <Route path="/blog-posts">
                      <Route index element={<BlogPostList />} />
                      <Route path="create" element={<BlogPostCreate />} />
                      <Route path="edit/:id" element={<BlogPostEdit />} />
                      <Route path="show/:id" element={<BlogPostShow />} />
                    </Route>
                    <Route path="/categories">
                      <Route index element={<CategoryList />} />
                      <Route path="create" element={<CategoryCreate />} />
                      <Route path="edit/:id" element={<CategoryEdit />} />
                      <Route path="show/:id" element={<CategoryShow />} />
                    </Route> */}

                    <Route path="/country">
                      <Route index element={<CountryList />} />
                      <Route path="create" element={<CountryCreate />} />
                      <Route path="edit/:name" element={<CountryEdit />} />
                    </Route>

                    <Route path="/city">
                      <Route index element={<CityList />} />
                      <Route path="create" element={<CityCreate />} />
                      <Route path="edit/:id" element={<CityEdit />} />
                    </Route>

                    <Route path="/carrier">
                      <Route index element={<CarrierList />} />
                      <Route path="create" element={<CarrierCreate />} />
                      <Route path="edit/:id" element={<CarrierEdit />} />
                    </Route>

                    <Route path="*" element={<ErrorComponent />} />
                  </Route>
                  <Route
                    element={
                      <Authenticated key="authenticated-outer" fallback={<Outlet />}>
                        <NavigateToResource />
                      </Authenticated>
                    }
                  >
                    <Route path="/login" element={<Login />} />
                    <Route path="/register" element={<Register />} />
                    <Route path="/forgot-password" element={<ForgotPassword />} />
                  </Route>
                </Routes>

                <RefineKbar />
                <UnsavedChangesNotifier />
                <DocumentTitleHandler />
              </Refine>
              <DevtoolsPanel />
            </DevtoolsProvider>
          </RefineSnackbarProvider>
        </ColorModeContextProvider>
      </RefineKbarProvider>
    </BrowserRouter>
  )
}

export default App
